import { ColorRepresentation, Matrix4, Vector2, Vector3, Vector4 } from 'three';
import { Compiler, CompileResult, ShaderNode } from './compiler';
export declare abstract class BooleanNode implements ShaderNode<string> {
    static readonly typeName = "bool";
    abstract compile(c: Compiler): any;
    isBoolean(): boolean;
    and(other: BooleanNode): BoolAddNode;
    or(other: BooleanNode): BoolOrNode;
}
export declare class ConstantBooleanNode extends BooleanNode {
    private readonly bool;
    constructor(bool: boolean);
    isBoolean(): boolean;
    compile(c: Compiler): {
        out: string;
    };
}
export declare class BoolBiOperatorNode extends BooleanNode {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IVec2Node, b: IVec2Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class BoolAddNode extends BoolBiOperatorNode {
    constructor(a: BooleanNode, b: BooleanNode);
}
export declare class BoolOrNode extends BoolBiOperatorNode {
    constructor(a: BooleanNode, b: BooleanNode);
}
export declare type IIntNode = ShaderNode & {};
export declare abstract class IntNode implements IIntNode {
    static readonly typeName = "int";
    abstract compile(c: Compiler): any;
    isInt(): boolean;
    add(other: IIntNode): IntAddNode;
    subtract(other: IIntNode): IntSubtractNode;
    multiply(other: IIntNode): IntMultiplyNode;
    gt(other: IntNode): BooleanNode;
    lt(other: IntNode): BooleanNode;
    gte(other: IntNode): BooleanNode;
    lte(other: IntNode): BooleanNode;
    equals(other: IntNode): BooleanNode;
    notEquals(other: IntNode): BooleanNode;
}
export declare class ConstantIntNode extends IntNode {
    readonly number: number;
    constructor(number: number);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class IntBiOperatorNode extends IntNode {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IIntNode, b: IIntNode, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class IntAddNode extends IntBiOperatorNode {
    constructor(a: IIntNode, b: IIntNode);
}
export declare class IntSubtractNode extends IntBiOperatorNode {
    constructor(a: IIntNode, b: IIntNode);
}
export declare class IntDivNode extends IntBiOperatorNode {
    constructor(a: IIntNode, b: IIntNode);
}
export declare class IntMultiplyNode extends IntBiOperatorNode {
    constructor(a: IIntNode, b: IIntNode);
}
export declare type IFloatNode = ShaderNode & {};
export declare abstract class FloatNode implements IFloatNode {
    static readonly typeName = "float";
    abstract compile(c: Compiler): any;
    isFloat(): boolean;
    add(other: IFloatNode): FloatAddNode;
    subtract(other: IFloatNode): FloatSubtractNode;
    divide(other: IFloatNode): FloatDivNode;
    multiply(other: IFloatNode): FloatMultiplyNode;
    multiplyVec2(other: IVec3Node): FloatVec2MultiplyNode;
    multiplyVec3(other: IVec3Node): FloatVec3MultiplyNode;
    multiplyVec4(other: IVec3Node): FloatVec4MultiplyNode;
    gt(other: FloatNode): BooleanNode;
    lt(other: FloatNode): BooleanNode;
    gte(other: FloatNode): BooleanNode;
    lte(other: FloatNode): BooleanNode;
    equals(other: FloatNode): BooleanNode;
    notEquals(other: FloatNode): BooleanNode;
}
export declare class ConstantFloatNode extends FloatNode {
    readonly number: number;
    constructor(number: number);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class FloatBiOperatorNode extends FloatNode {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IFloatNode, b: IFloatNode, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class FloatAddNode extends FloatBiOperatorNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatSubtractNode extends FloatBiOperatorNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatDivNode extends FloatBiOperatorNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare class FloatMultiplyNode extends FloatBiOperatorNode {
    constructor(a: IFloatNode, b: IFloatNode);
}
export declare type IVec2Node = ShaderNode & {};
export declare type IVec3Node = ShaderNode & {};
export declare type IVec4Node = ShaderNode & {};
export declare type IRgbNode = ShaderNode & {};
export declare type IRgbaNode = ShaderNode & {};
export declare type IMat2Node = ShaderNode & {};
export declare type IMat3Node = ShaderNode & {};
export declare type IMat4Node = ShaderNode & {};
export declare abstract class Vec2Node implements IVec2Node {
    static readonly typeName = "vec2";
    abstract compile(c: Compiler): any;
    isVec2(): boolean;
    x(): GetFloatComponentNode;
    y(): GetFloatComponentNode;
    subtractScalar(other: FloatNode): Vec2Node;
    subtract(other: Vec2Node): Vec2Node;
    addScalar(other: FloatNode): Vec2Node;
    add(other: Vec2Node): Vec2Node;
    divideScalar(other: FloatNode): Vec2Node;
    divide(other: Vec2Node): Vec2Node;
    multiplyScalar(other: FloatNode): Vec2Node;
    multiply(other: Vec2Node): Vec2Node;
    multiplyMat(other: Mat2Node): Vec2Node;
    equals(other: Vec2Node): BooleanNode;
    notEquals(other: Vec2Node): BooleanNode;
}
export declare class ConstantVec2Node extends Vec2Node {
    private readonly vec;
    constructor(vec: Vector2 | Vector3 | Vector4);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsVec2Node extends Vec2Node {
    private readonly _x;
    private readonly _y;
    constructor(_x: IFloatNode, _y: IFloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class Vec2BiOperatorNode extends Vec2Node {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IVec2Node, b: IVec2Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Vec2AddNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IVec2Node);
}
export declare class Vec2SubtractNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IVec2Node);
}
export declare class Vec2FloatAddNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IFloatNode);
}
export declare class Vec2FloatSubtractNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IFloatNode);
}
export declare class Vec2FloatMultiplyNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IFloatNode);
}
export declare class Vec2FloatDivideNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IFloatNode);
}
export declare class Vec2DivNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IVec2Node);
}
export declare class Vec2MultiplyNode extends Vec2BiOperatorNode {
    constructor(a: IVec2Node, b: IVec2Node);
}
export declare class FloatVec2MultiplyNode extends Vec2BiOperatorNode {
    constructor(a: IFloatNode, b: IVec2Node);
}
export declare abstract class Vec3Node implements IVec3Node {
    static readonly typeName = "vec3";
    abstract compile(c: Compiler): any;
    isVec3(): boolean;
    x(): GetFloatComponentNode;
    y(): GetFloatComponentNode;
    z(): GetFloatComponentNode;
    xy(): ComponentsVec2Node;
    xz(): ComponentsVec2Node;
    yz(): ComponentsVec2Node;
    zx(): ComponentsVec2Node;
    rgb(): ComponentsRgbNode;
    subtractScalar(other: FloatNode): Vec3Node;
    subtract(other: Vec3Node): Vec3Node;
    addScalar(other: FloatNode): Vec3Node;
    add(other: Vec3Node): Vec3Node;
    divideScalar(other: FloatNode): Vec3Node;
    divide(other: Vec3Node): Vec3Node;
    multiplyScalar(other: FloatNode): Vec3Node;
    multiply(other: Vec3Node): Vec3Node;
    multiplyMat(other: Mat3Node): Vec3Node;
    equals(other: Vec3Node): BooleanNode;
    notEquals(other: Vec3Node): BooleanNode;
}
export declare class ConstantVec3Node extends Vec3Node {
    private readonly vec;
    constructor(vec: Vector3 | Vector4);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsVec3Node extends Vec3Node {
    private readonly _x;
    private readonly _y;
    private readonly _z;
    constructor(_x: IFloatNode, _y: IFloatNode, _z: IFloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class Vec3BiOperatorNode extends Vec3Node {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IVec3Node, b: IVec3Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Vec3AddNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IVec3Node);
}
export declare class Vec3SubtractNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IVec3Node);
}
export declare class Vec3FloatAddNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IFloatNode);
}
export declare class Vec3FloatSubtractNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IFloatNode);
}
export declare class Vec3FloatMultiplyNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IFloatNode);
}
export declare class Vec3FloatDivideNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IFloatNode);
}
export declare class Vec3DivNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IVec3Node);
}
export declare class Vec3MultiplyNode extends Vec3BiOperatorNode {
    constructor(a: IVec3Node, b: IVec3Node);
}
export declare class FloatVec3MultiplyNode extends Vec3BiOperatorNode {
    constructor(a: IFloatNode, b: IVec3Node);
}
export declare abstract class Vec4Node implements IVec4Node {
    static readonly typeName = "vec4";
    abstract compile(c: Compiler): any;
    isVec4(): boolean;
    x(): GetFloatComponentNode;
    y(): GetFloatComponentNode;
    z(): GetFloatComponentNode;
    w(): GetFloatComponentNode;
    xy(): ComponentsVec2Node;
    xz(): ComponentsVec2Node;
    yz(): ComponentsVec2Node;
    zx(): ComponentsVec2Node;
    xyz(): ComponentsVec3Node;
    rgb(): ComponentsRgbNode;
    rgba(): ComponentsRgbaNode;
    subtractScalar(other: FloatNode): Vec4Node;
    subtract(other: Vec4Node): Vec4Node;
    addScalar(other: FloatNode): Vec4Node;
    add(other: Vec4Node): Vec4Node;
    divideScalar(other: FloatNode): Vec4Node;
    divide(other: Vec4Node): Vec4Node;
    multiplyScalar(other: FloatNode): Vec4Node;
    multiply(other: Vec4Node): Vec4Node;
    multiplyMat(other: Mat4Node): Vec4Node;
    equals(other: Vec4Node): BooleanNode;
    notEquals(other: Vec4Node): BooleanNode;
}
export declare class ConstantVec4Node extends Vec4Node {
    private readonly vec;
    constructor(vec: Vector4);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsVec4Node extends Vec4Node {
    private readonly _x;
    private readonly _y;
    private readonly _z;
    private readonly _w;
    constructor(_x: IFloatNode, _y: IFloatNode, _z: IFloatNode, _w: IFloatNode);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Vec4BiOperatorNode extends Vec4Node {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IVec4Node, b: IVec4Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Vec4AddNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IVec4Node);
}
export declare class Vec4SubtractNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IVec4Node);
}
export declare class Vec4FloatAddNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IFloatNode);
}
export declare class Vec4FloatSubtractNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IFloatNode);
}
export declare class Vec4FloatMultiplyNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IFloatNode);
}
export declare class Vec4FloatDivideNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IFloatNode);
}
export declare class Vec4DivNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IVec4Node);
}
export declare class Vec4MultiplyNode extends Vec4BiOperatorNode {
    constructor(a: IVec4Node, b: IVec4Node);
}
export declare class FloatVec4MultiplyNode extends Vec4BiOperatorNode {
    constructor(a: IFloatNode, b: IVec4Node);
}
export declare abstract class Mat2Node implements IMat2Node {
    static readonly typeName = "mat2";
    abstract compile(c: Compiler): any;
    isMat2(): boolean;
    add(other: Mat2Node): Mat2Node;
    subtract(other: Mat2Node): Mat2Node;
    divideScalar(other: FloatNode): Mat2Node;
    multiplyScalar(other: Vec2Node): Mat2Node;
    multiplyVec(other: Vec2Node): Vec2Node;
    multiply(other: Mat2Node): Mat2Node;
    equals(other: Mat2Node): BooleanNode;
    notEquals(other: Mat2Node): BooleanNode;
}
export declare class ConstantMat2Node extends Mat2Node {
    private readonly a;
    private readonly b;
    private readonly c;
    private readonly d;
    constructor(a: number, b: number, c: number, d: number);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsMat2Node extends Mat2Node {
    private readonly a;
    private readonly b;
    private readonly c;
    private readonly d;
    constructor(a: IFloatNode, b: IFloatNode, c: IFloatNode, d: IFloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class Mat2BiOperatorNode extends Mat2Node {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IMat2Node, b: IMat2Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Mat2AddNode extends Mat2BiOperatorNode {
    constructor(a: IMat2Node, b: IMat2Node);
}
export declare class Mat2SubtractNode extends Mat2BiOperatorNode {
    constructor(a: IMat2Node, b: IMat2Node);
}
export declare class Mat2MultiplyNode extends Mat2BiOperatorNode {
    constructor(a: IMat2Node, b: IMat2Node);
}
export declare class Mat2FloatDivNode extends Mat2BiOperatorNode {
    constructor(a: IMat2Node, b: IFloatNode);
}
export declare class Mat2FloatMultiplyNode extends Mat2BiOperatorNode {
    constructor(a: IMat2Node, b: IFloatNode);
}
export declare class VecMat2MultiplyNode extends Vec2BiOperatorNode {
    constructor(a: Vec2Node, b: Mat2Node);
}
export declare class MatVec2MultiplyNode extends Vec2BiOperatorNode {
    constructor(a: Mat2Node, b: Vec2Node);
}
export declare abstract class Mat3Node implements IMat3Node {
    static readonly typeName = "mat3";
    abstract compile(c: Compiler): any;
    isMat3(): boolean;
    add(other: Mat3Node): Mat3Node;
    subtract(other: Mat3Node): Mat3Node;
    divideScalar(other: FloatNode): Mat3Node;
    multiplyScalar(other: Vec3Node): Mat3Node;
    multiplyVec(other: Vec3Node): Vec3Node;
    multiply(other: Mat3Node): Mat3Node;
    equals(other: Mat3Node): BooleanNode;
    notEquals(other: Mat3Node): BooleanNode;
}
export declare class ConstantMat3Node extends Mat3Node {
    private readonly a;
    private readonly b;
    private readonly c;
    private readonly d;
    private readonly e;
    private readonly f;
    private readonly g;
    private readonly h;
    private readonly i;
    constructor(a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsMat3Node extends Mat3Node {
    private readonly a;
    private readonly b;
    private readonly c;
    private readonly d;
    private readonly e;
    private readonly f;
    private readonly g;
    private readonly h;
    private readonly i;
    constructor(a: FloatNode, b: FloatNode, c: FloatNode, d: FloatNode, e: FloatNode, f: FloatNode, g: FloatNode, h: FloatNode, i: FloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class Mat3BiOperatorNode extends Mat3Node {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IMat3Node, b: IMat3Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Mat3AddNode extends Mat3BiOperatorNode {
    constructor(a: IMat3Node, b: IMat3Node);
}
export declare class Mat3SubtractNode extends Mat3BiOperatorNode {
    constructor(a: IMat3Node, b: IMat3Node);
}
export declare class Mat3MultiplyNode extends Mat3BiOperatorNode {
    constructor(a: IMat3Node, b: IMat3Node);
}
export declare class Mat3FloatDivNode extends Mat3BiOperatorNode {
    constructor(a: IMat3Node, b: IFloatNode);
}
export declare class Mat3FloatMultiplyNode extends Mat3BiOperatorNode {
    constructor(a: IMat3Node, b: IFloatNode);
}
export declare class VecMat3MultiplyNode extends Vec3BiOperatorNode {
    constructor(a: Vec3Node, b: Mat3Node);
}
export declare class MatVec3MultiplyNode extends Vec3BiOperatorNode {
    constructor(a: Mat3Node, b: Vec3Node);
}
export declare abstract class Mat4Node implements IMat4Node {
    static readonly typeName = "mat4";
    abstract compile(c: Compiler): any;
    isMat4(): boolean;
    add(other: Mat4Node): Mat4Node;
    subtract(other: Mat4Node): Mat4Node;
    divideScalar(other: FloatNode): Mat4Node;
    multiplyScalar(other: FloatNode): Mat4Node;
    multiplyVec(other: Vec4Node): Vec4Node;
    multiply(other: Mat4Node): Mat4Node;
    equals(other: Mat4Node): BooleanNode;
    notEquals(other: Mat4Node): BooleanNode;
}
export declare class ConstantMat4Node extends Mat4Node {
    private readonly a1;
    private readonly b1?;
    private readonly c1?;
    private readonly d1?;
    private readonly a2?;
    private readonly b2?;
    private readonly c2?;
    private readonly d2?;
    private readonly a3?;
    private readonly b3?;
    private readonly c3?;
    private readonly d3?;
    private readonly a4?;
    private readonly b4?;
    private readonly c4?;
    private readonly d4?;
    constructor(a1: number | Matrix4, b1?: number | undefined, c1?: number | undefined, d1?: number | undefined, a2?: number | undefined, b2?: number | undefined, c2?: number | undefined, d2?: number | undefined, a3?: number | undefined, b3?: number | undefined, c3?: number | undefined, d3?: number | undefined, a4?: number | undefined, b4?: number | undefined, c4?: number | undefined, d4?: number | undefined);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsMat4Node extends Mat4Node {
    private readonly a1;
    private readonly b1;
    private readonly c1;
    private readonly d1;
    private readonly a2;
    private readonly b2;
    private readonly c2;
    private readonly d2;
    private readonly a3;
    private readonly b3;
    private readonly c3;
    private readonly d3;
    private readonly a4;
    private readonly b4;
    private readonly c4;
    private readonly d4;
    constructor(a1: IFloatNode, b1: IFloatNode, c1: IFloatNode, d1: IFloatNode, a2: IFloatNode, b2: IFloatNode, c2: IFloatNode, d2: IFloatNode, a3: IFloatNode, b3: IFloatNode, c3: IFloatNode, d3: IFloatNode, a4: IFloatNode, b4: IFloatNode, c4: IFloatNode, d4: IFloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class Mat4BiOperatorNode extends Mat4Node {
    private readonly a;
    private readonly b;
    private readonly op;
    constructor(a: IMat4Node, b: IMat4Node, op: string);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class Mat4AddNode extends Mat4BiOperatorNode {
    constructor(a: IMat4Node, b: IMat4Node);
}
export declare class Mat4SubtractNode extends Mat4BiOperatorNode {
    constructor(a: IMat4Node, b: IMat4Node);
}
export declare class Mat4MultiplyNode extends Mat4BiOperatorNode {
    constructor(a: IMat4Node, b: IMat4Node);
}
export declare class Mat4FloatDivNode extends Mat4BiOperatorNode {
    constructor(a: IMat4Node, b: IFloatNode);
}
export declare class Mat4FloatMultiplyNode extends Mat4BiOperatorNode {
    constructor(a: IMat4Node, b: IFloatNode);
}
export declare class VecMat4MultiplyNode extends Vec4BiOperatorNode {
    constructor(a: Vec4Node, b: Mat4Node);
}
export declare class MatVec4MultiplyNode extends Vec4BiOperatorNode {
    constructor(a: Mat4Node, b: Vec4Node);
}
export declare abstract class RgbaNode extends Vec4Node implements IRgbaNode {
    abstract compile(c: Compiler): any;
    isRgba(): boolean;
    r(): GetFloatComponentNode;
    g(): GetFloatComponentNode;
    b(): GetFloatComponentNode;
    a(): GetFloatComponentNode;
}
export declare class ConstantRgbaNode extends RgbaNode {
    readonly color: ColorRepresentation;
    private readonly alpha;
    constructor(color: ColorRepresentation, alpha?: number);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare abstract class RgbNode extends Vec3Node implements IRgbNode {
    abstract compile(c: Compiler): any;
    isRgb(): boolean;
    r(): GetFloatComponentNode;
    g(): GetFloatComponentNode;
    b(): GetFloatComponentNode;
    rgba(alpha: IFloatNode): RgbToRgbaNode;
}
export declare class ComponentsRgbaNode extends RgbaNode {
    private readonly _r;
    private readonly _g;
    private readonly _b;
    private readonly _a;
    constructor(_r: IFloatNode, _g: IFloatNode, _b: IFloatNode, _a: IFloatNode);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ComponentsRgbNode extends RgbNode {
    private readonly _r;
    private readonly _g;
    private readonly _b;
    constructor(_r: IFloatNode, _g: IFloatNode, _b: IFloatNode);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class ConstantRgbNode extends RgbNode {
    private readonly color;
    constructor(color: ColorRepresentation);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class RgbToRgbaNode implements IRgbaNode {
    private readonly rgb;
    private readonly alpha;
    constructor(rgb: RgbNode, alpha: IFloatNode);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export declare class RgbaToRgbNode implements IRgbNode {
    private readonly rgb;
    constructor(rgb: RgbaNode);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
declare class GetFloatComponentNode extends FloatNode {
    private readonly vec;
    private readonly component;
    constructor(vec: IVec3Node, component: string);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class GtNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: FloatNode, b: FloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class LtNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: FloatNode, b: FloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class GteNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: FloatNode, b: FloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class LteNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: FloatNode, b: FloatNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class IntGtNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: IntNode, b: IntNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class IntLtNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: IntNode, b: IntNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class IntGteNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: IntNode, b: IntNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class IntLteNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: IntNode, b: IntNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare class EqualsNode extends BooleanNode {
    private readonly a;
    private readonly b;
    constructor(a: IntNode, b: IntNode);
    compile(c: Compiler): {
        out: string;
    };
}
export declare abstract class Sampler2DNode implements ShaderNode<string> {
    static readonly typeName = "sampler2D";
    abstract compile(c: Compiler): CompileResult<string>;
    sample(cord: Vec2Node, bias?: FloatNode): RgbaNode;
}
export declare class Texture2dLookupNode extends RgbaNode {
    private readonly sampler;
    private readonly cord;
    private readonly bias?;
    constructor(sampler: Sampler2DNode, cord: Vec2Node, bias?: FloatNode | undefined);
    compile(c: Compiler): {
        chunk: string;
        out: string;
    };
}
export {};
